##  Subscription to Fact Sheets
  * Purpose: Assign responsibility and accountability for maintaining data accuracy.
  * Functionality: Subscription to fact sheets assigns responsibility to specific contributors, ensuring they stay engaged with the fact sheet data. Subscribers receive notifications and clear calls to action for maintaining and administering fact sheet data.
  * Benefits: It promotes the active involvement of key stakeholders, drives SAP LeanIX adoption across the organization, and ensures the ongoing accuracy and completeness of data.


For a detailed guide, see [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
